Module contexts

Module contexts 

This module contains abstractions of the libretro environment callbacks.

Structs

AudioContext
Functions that are safe to be called in Core::on_write_audio.
GenericContext
Exposes environment callbacks that are safe to call in every context.
GetAvInfoContext
Functions that are safe to be called in Core::on_get_av_info
InitContext
Functions that are safe to be called in Core::on_init
LoadGameContext
Functions that are safe to be called in Core::on_load_game.
LoadGameSpecialContext
Functions that are safe to be called in Core::on_load_game_special
OptionsChangedContext
Functions that are safe to be called in Core::on_options_changed
RunContext
Functions that are safe to be called in Core::on_run.
SetEnvironmentContext
Functions that are safe to be called in Core::on_set_environment

Statics

FALLBACK_FRAMEBUFFER 🔒
This would only be used in Core::on_run from a single thread.

Type Aliases

CheatResetContext
Functions that are safe to be called in Core::on_cheat_reset.
CheatSetContext
Functions that are safe to be called in Core::on_cheat_set.
DeinitContext
Functions that are safe to be called in Core::on_deinit.
GetMemoryDataContext
Functions that are safe to be called in Core::get_memory_data.
GetMemorySizeContext
Functions that are safe to be called in Core::get_memory_size.
GetRegionContext
Functions that are safe to be called in Core::on_get_region.
GetSerializeSizeContext
Functions that are safe to be called in Core::get_serialize_size.
ResetContext
Functions that are safe to be called in Core::on_reset.
SerializeContext
Functions that are safe to be called in Core::on_serialize.
UnloadGameContext
Functions that are safe to be called in Core::on_unload_game.
UnserializeContext
Functions that are safe to be called in Core::on_unserialize.