Function rust_libretro::environment::get

source ·
pub unsafe fn get<T: Default>(
    callback: retro_environment_t,
    id: u32
) -> Option<(T, bool)>
Gets a value from an environment callback.

The first value of the return type is the queried data, the second value is the return value of the callback itself.