pub unsafe fn get_hw_render_interface_vulkan(
    callback: retro_environment_t
) -> Option<retro_hw_render_interface_vulkan>
Unstable See get_hw_render_interface.

This feature is unstable and guarded by the unstable-env-commands feature flag.

Please be advised that this feature might change without further notice and no guarantees about its stability can be made.