pub unsafe fn set_core_options_update_display_callback(
    callback: retro_environment_t,
    data: retro_core_options_update_display_callback
) -> bool
Allows a frontend to signal that a core must update the visibility of any dynamically hidden core options, and enables the frontend to detect visibility changes.

Used by the frontend to update the menu display status of core options without requiring a call of Core::on_run. Must be called in Core::on_set_environment.