pub unsafe fn set_hw_render(
    callback: retro_environment_t,
    data: retro_hw_render_callback
) -> bool
Sets an interface to let a libretro core render with hardware acceleration.

If successful, libretro cores will be able to render to a frontend-provided framebuffer. The size of this framebuffer will be at least as large as max_width/max_height provided in Core::on_get_av_info. If HW rendering is used, call either RunContext::draw_hardware_frame or RunContext::dupe_frame.