Function rust_libretro::environment::set_frame_time_callback
source · pub unsafe fn set_frame_time_callback(
callback: retro_environment_t,
data: retro_frame_time_callback
) -> boolExpand description
Lets the core know how much time has passed since last
invocation of Core::on_run.
The frontend can tamper with the timing to fake fast-forward,
slow-motion, frame stepping, etc.
In this case the delta time will use the reference value
in retro_frame_time_callback.