Function rust_libretro::environment::set_pixel_format
source · pub unsafe fn set_pixel_format<F: Into<retro_pixel_format>>(
callback: retro_environment_t,
format: F
) -> boolExpand description
Sets the internal pixel format used by the implementation.
The default pixel format is retro_pixel_format::RETRO_PIXEL_FORMAT_0RGB1555.
This pixel format however, is deprecated (see enum retro_pixel_format).
If the call returns false, the frontend does not support this pixel
format.