Function rust_libretro::environment::set_proc_address_callback
source · pub unsafe fn set_proc_address_callback(
callback: retro_environment_t,
data: retro_get_proc_address_interface
) -> boolExpand description
Allows a libretro core to announce support for the
retro_get_proc_address_interface interface.
This interface allows for a standard way to extend libretro where
use of environment calls are too indirect,
e.g. for cases where the frontend wants to call directly into the core.
If a core wants to expose this interface, set_proc_address_callback
MUST be called from within Core::on_set_environment.